@@ -24,7 +24,7 @@
 #' @examples
 #' \dontrun{
 #' library(MazamaSpatialUtils)
-#' setSpatialDataDir("~/Data/Spatial")
+#' setSpatialDataDir("~/Data/Spatial_0.8")
 #'
 #' loadSpatialData("USCensusCounties")
 #'
@@ -59,24 +59,16 @@ getUSCounty <- function(
          call. = FALSE)
   }
 
-  # Check longitude, latitude ranges
-  if ( min(longitude, na.rm = TRUE) < -180 ||
-       max(longitude, na.rm = TRUE) > 180) {
-    stop("'longitude' must be specified in the range -180:180.")
-  }
-  if ( min(latitude, na.rm = TRUE) < -90 ||
-       max(latitude, na.rm = TRUE) > 90 ) {
-    stop("'latitude' must be specified in the range -90:90.")
-  }
+  MazamaCoreUtils::validateLonsLats(longitude, latitude, na.rm = TRUE)
 
   # ----- Get the data ---------------------------------------------------------
 
-  SPDF <- get(dataset)
+  SFDF <- get(dataset)
 
   # Subset by state before searching
-  if (!is.null(stateCodes)) SPDF <- SPDF[SPDF$stateCode %in% stateCodes,]
+  if (!is.null(stateCodes)) SFDF <- SFDF[SFDF$stateCode %in% stateCodes,]
 
-  locationsDF <- getSpatialData(longitude, latitude, SPDF, useBuffering = useBuffering)
+  locationsDF <- getSpatialData(longitude, latitude, SFDF, useBuffering = useBuffering)
 
   if (allData) {
 
